@@ -15,7 +15,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from typing import Any, Callable, Dict, Optional, Type
+from typing import TYPE_CHECKING, Any, Callable, Dict, Optional, Sequence, Type
 
 from requests.auth import AuthBase, HTTPBasicAuth
 
@@ -23,6 +23,9 @@ from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
 from airflow.providers.http.hooks.http import HttpHook
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class SimpleHttpOperator(BaseOperator):
     """
@@ -65,13 +68,13 @@ class SimpleHttpOperator(BaseOperator):
     :type auth_type: AuthBase of python requests lib
     """
 
-    template_fields = [
+    template_fields: Sequence[str] = (
         'endpoint',
         'data',
         'headers',
-    ]
+    )
     template_fields_renderers = {'headers': 'json', 'data': 'py'}
-    template_ext = ()
+    template_ext: Sequence[str] = ()
     ui_color = '#f4a460'
 
     def __init__(
@@ -103,8 +106,8 @@ class SimpleHttpOperator(BaseOperator):
         if kwargs.get('xcom_push') is not None:
             raise AirflowException("'xcom_push' was deprecated, use 'BaseOperator.do_xcom_push' instead")
 
-    def execute(self, context: Dict[str, Any]) -> Any:
-        from airflow.utils.operator_helpers import make_kwargs_callable
+    def execute(self, context: 'Context') -> Any:
+        from airflow.utils.operator_helpers import determine_kwargs
 
         http = HttpHook(self.method, http_conn_id=self.http_conn_id, auth_type=self.auth_type)
 
@@ -114,10 +117,10 @@ class SimpleHttpOperator(BaseOperator):
         if self.log_response:
             self.log.info(response.text)
         if self.response_check:
-            kwargs_callable = make_kwargs_callable(self.response_check)
-            if not kwargs_callable(response, **context):
+            kwargs = determine_kwargs(self.response_check, [response], context)
+            if not self.response_check(response, **kwargs):
                 raise AirflowException("Response check returned False.")
         if self.response_filter:
-            kwargs_callable = make_kwargs_callable(self.response_filter)
-            return kwargs_callable(response, **context)
+            kwargs = determine_kwargs(self.response_filter, [response], context)
+            return self.response_filter(response, **kwargs)
         return response.text
